@@ -9,6 +9,12 @@ from json import loads
 import requests
 from bs4 import BeautifulSoup
 import numpy as np
+import uuid
+
+from IPython.display import display, HTML
+
+import json
+
 
 
 def doomsday_clock(year):
@@ -144,6 +150,26 @@ def get_eq_info():
     return q.get("earthquake", {})
 
 
+class pprint(object):
+    def __init__(self, json_data):
+        if isinstance(json_data, dict):
+            self.json_str = json.dumps(json_data)
+        else:
+            self.json_str = json_data
+        self.uuid = str(uuid.uuid4())
+        # This line is missed out in most of the versions of this script across the web, it is essential for this to work interleaved with print statements
+        self._ipython_display_()
+        
+    def _ipython_display_(self):
+        display(HTML('<div id="{}" style="height: auto; width:100%;"></div>'.format(self.uuid)))
+        display(HTML("""<script>
+        require(["https://rawgit.com/caldwell/renderjson/master/renderjson.js"], function() {
+          renderjson.set_show_to_level(1)
+          document.getElementById('%s').appendChild(renderjson(%s))
+        });</script>
+        """ % (self.uuid, self.json_str)))
+
+
 def get_eq_info2():
     """
     api.p2pquake.netから，日本で発生した直近の地震の情報を取り出す
